RunnerStarted class

Inheritance

Constructors

RunnerStarted(DateTime at, {Duration? elapsed, String? entrypoint, String? serviceUri, String? devToolsUri})
const

Properties

at → DateTime
finalinherited
devToolsUri → String?
final
elapsed → Duration?
final
entrypoint → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceUri → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited