FileChanged class
Raw file-system signal, emitted after filtering but before debounce. Use this to react to every accepted file event, even ones that get coalesced into a single CompileStarted by the debounce window.
- Inheritance
-
- Object
- RunnerEvent
- FileChanged
Constructors
- FileChanged(DateTime at, FsEvent change)
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited